@@ -12,6 +12,6 @@ func TestHyperlinkToNormal(t *testing.T) {
 
 	style := StyleDefault.WithHyperlink(&url)
 	assert.Equal(t,
-		strings.ReplaceAll(StyleDefault.RenderUpdateFrom(style, ColorCount16), "", "ESC"),
+		strings.ReplaceAll(StyleDefault.RenderUpdateFrom(style, ColorCount16), "\x1b", "ESC"),
 		"ESC]8;;ESC\\")
 }
